@@ -1,9 +1,11 @@
 __all__ = [
     'Minuit',
     'describe',
-    'Struct'
-    'InitialParamWarning'
+    'Struct',
+    'InitialParamWarning',
+    '__version__'
 ]
 from _libiminuit import *
 from util import describe, Struct
 from iminuit_warnings import *
+from info import __version__
