@@ -23,8 +23,9 @@ class LatexTable:
         'Chi', 'Psi', 'Omega',
     ]
 
-    def __init__(self, data, headers=None, smart_latex=True,
-                alignment=None):
+    def __init__(self, data, headers=None, smart_latex=True, 
+                escape_under_score=True, alignment=None, rotate_header=False,
+                latex_map=None):
         if headers is not None:
             assert(len(headers) == len(data[0]))
 
@@ -32,8 +33,10 @@ class LatexTable:
         self.data = data
         self.num_col = len(data[0])
         self.smart_latex = smart_latex
+        self.escape_under_score = escape_under_score
         self.alignment = self._auto_align() if alignment is None else alignment
-
+        self.rotate_header = rotate_header
+        self.latex_map = {} if latex_map is None else latex_map
         self.cell_color = {}#map of tuple (i,j)=>(r, g, b) #i,j include header
 
     def _auto_align(self):
@@ -43,12 +46,16 @@ class LatexTable:
         return '[RGB]{%d,%d,%d}'%(c[0], c[1], c[2])
 
     def _format(self, s):
-        if isinstance(s, float):
+        if s in self.latex_map:
+            return self.latex_map[s]
+        elif isinstance(s, float):
             return self.float_format%s
         elif isinstance(s, int):
             return self.int_format%s
         elif self.smart_latex:
             return self._convert_smart_latex(s)
+        elif self.escape_under_score:
+            return s.replace('_',r'\_')
         else:
             return s
 
@@ -89,7 +96,11 @@ class LatexTable:
     def _prepare(self): #return list of list
         ret = []
         if self.headers:
-            ret.append(map(self._format, self.headers))
+            tmp = map(self._format, self.headers)
+            if self.rotate_header:
+                tmp = map(lambda x: '\\rotatebox{90}{%s}'%x, tmp)
+
+            ret.append(tmp)
         for x in self.data:
             ret.append(map(self._format, x))
         return ret
@@ -99,6 +110,7 @@ class LatexTable:
         ret = ''
         if len(self.cell_color) != 0:
             ret += '%\\usepackage[table]{xcolor} % include this for color\n'
+            ret += '%\\usepackage{rotating} % include this for rotate header\n'
             ret += '%\\documentclass[xcolor=table]{beamer} % for beamer\n'
         ret += '\\begin{tabular}{%s}\n'%(self.alignment)
         ret += hline
@@ -119,7 +131,7 @@ class LatexTable:
 class LatexFactory:
 
     @classmethod
-    def build_matrix(self, vnames, matrix):
+    def build_matrix(self, vnames, matrix, latex_map=None):
         """build latex correlation matrix"""
         #ret_link  = '<a onclick="$(\'#%s\').toggle()" href="#">Show Latex</a>'%uid
         headers = ['']+list(vnames)
@@ -134,14 +146,16 @@ class LatexFactory:
                 # +1 for header on the side and top
             data.append(tmp)
 
-        table = LatexTable(headers=headers, data=data)
+        table = LatexTable(headers=headers, data=data, rotate_header=True,
+                           latex_map=latex_map)
         table.float_format = '%3.2f'
         for (i, j), c in color.items():
             table.set_cell_color(i, j, c)
         return table
 
     @classmethod
-    def build_param_table(self, mps, merr=None, float_format='%5.3e'):
+    def build_param_table(self, mps, merr=None, float_format='%5.3e',
+                        smart_latex=True, latex_map=None):
         """build latex parameter table"""
         headers = ['', 'Name', 'Value', 'Para Error', 'Error+',
                    'Error-', 'Limit+', 'Limit-', 'FIXED', ]
@@ -167,6 +181,7 @@ class LatexFactory:
             ]
             data.append(tmp)
         alignment = '|c|r|r|r|r|r|r|r|c|'
-        ret = LatexTable(data, headers=headers, alignment=alignment)
-        ret.float_format = '%5.3e'
+        ret = LatexTable(data, headers=headers, alignment=alignment,
+                        smart_latex=smart_latex, latex_map=latex_map)
+        ret.float_format = float_format
         return ret
